//+---------------------------------------------------------------------------
//
//  Microsoft Windows
//  Copyright (c) Microsoft Corporation.  All rights reserved.
//
//  File:       guiddef.h
//
//  Contents:   GUID definition
//
//----------------------------------------------------------------------------

#ifndef INCLUDED_GUIDDEF_H
#define INCLUDED_GUIDDEF_H

#ifndef INCLUDED_BASETSD_H
#include <basetsd.h>
#endif

#ifndef GUID_DEFINED		/* Used to be compatible with Win95 */
#define GUID_DEFINED
#if defined(__midl)
typedef struct {
    unsigned long  Data1;
    unsigned short Data2;
    unsigned short Data3;
    byte Data4[ 8 ];
} GUID;
#else
typedef struct _GUID {
    DWORD  Data1;
    WORD Data2;
    WORD Data3;
    BYTE Data4[8];
} GUID;
#endif
#endif

#ifdef DEFINE_GUID
#undef DEFINE_GUID
#endif

#ifdef INITGUID
#define DEFINE_GUID(name, l, w1, w2, b1, b2, b3, b4, b5, b6, b7, b8) \
	EXTERN_C const GUID DECLSPEC_SELECTANY name = { l, w1, w2, { b1, b2,  b3,  b4,  b5,  b6,  b7,  b8 } }
#else
#define DEFINE_GUID(name, l, w1, w2, b1, b2, b3, b4, b5, b6, b7, b8) EXTERN_C const GUID FAR name
#endif

#define DEFINE_OLEGUID(name, l, w1, w2) DEFINE_GUID(name, l, w1, w2, 0xC0,0,0,0,0,0,0,0x46)

typedef GUID *LPGUID;
typedef const GUID *LPCGUID;

typedef GUID IID;
typedef IID *LPIID;
#define IID_NULL GUID_NULL
#define IsEqualIID(riid1, riid2) IsEqualGUID(riid1, riid2)

typedef GUID CLSID;
typedef CLSID *LPCLSID;
#define CLSID_NULL GUID_NULL
#define IsEqualCLSID(rclsid1, rclsid2) IsEqualGUID(rclsid1, rclsid2)

typedef GUID FMTID;
typedef FMTID *LPFMTID;
#define FMTID_NULL GUID_NULL
#define IsEqualFMTID(rfmtid1, rfmtid2) IsEqualGUID(rfmtid1, rfmtid2)

#ifdef __midl_proxy
#define __MIDL_CONST
#else
#define __MIDL_CONST const
#endif

#ifdef __cplusplus
#define REFGUID const GUID &
#define REFIID const IID &
#define REFCLSID const CLSID &
#define REFFMTID const IID &
#else
#define REFGUID const GUID * __MIDL_CONST
#define REFIID const IID * __MIDL_CONST
#define REFCLSID const IID * __MIDL_CONST
#define REFFMTID const IID * __MIDL_CONST
#endif

#if !defined (__midl)
// Faster (but makes code fatter) inline version...use sparingly
#ifdef __cplusplus
inline int InlineIsEqualGUID(REFGUID rguid1, REFGUID rguid2)
{
   return (
      (reinterpret_cast<const DWORD *>(&rguid1)[0] == reinterpret_cast<const DWORD *>(&rguid2)[0]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[1] == reinterpret_cast<const DWORD *>(&rguid2)[1]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[2] == reinterpret_cast<const DWORD *>(&rguid2)[2]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[3] == reinterpret_cast<const DWORD *>(&rguid2)[3]));
}

inline int IsEqualGUID(REFGUID rguid1, REFGUID rguid2)
{
   return (
      (reinterpret_cast<const DWORD *>(&rguid1)[0] == reinterpret_cast<const DWORD *>(&rguid2)[0]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[1] == reinterpret_cast<const DWORD *>(&rguid2)[1]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[2] == reinterpret_cast<const DWORD *>(&rguid2)[2]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[3] == reinterpret_cast<const DWORD *>(&rguid2)[3]));
}

#if !defined(_NO_SYS_GUID_OPERATOR_EQ_)
// A couple of C++ helpers
inline int operator==(REFGUID rguid1, REFGUID rguid2)
{
   return (
      (reinterpret_cast<const DWORD *>(&rguid1)[0] == reinterpret_cast<const DWORD *>(&rguid2)[0]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[1] == reinterpret_cast<const DWORD *>(&rguid2)[1]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[2] == reinterpret_cast<const DWORD *>(&rguid2)[2]) &&
      (reinterpret_cast<const DWORD *>(&rguid1)[3] == reinterpret_cast<const DWORD *>(&rguid2)[3]));
}

inline int operator!=(REFGUID rguid1, REFGUID rguid2)
{
   return (
      (reinterpret_cast<const DWORD *>(&rguid1)[0] != reinterpret_cast<const DWORD *>(&rguid2)[0]) ||
      (reinterpret_cast<const DWORD *>(&rguid1)[1] != reinterpret_cast<const DWORD *>(&rguid2)[1]) ||
      (reinterpret_cast<const DWORD *>(&rguid1)[2] != reinterpret_cast<const DWORD *>(&rguid2)[2]) ||
      (reinterpret_cast<const DWORD *>(&rguid1)[3] != reinterpret_cast<const DWORD *>(&rguid2)[3]));
}
#endif

#else   // ! __cplusplus

#define InlineIsEqualGUID(rguid1, rguid2)  \
        (((const DWORD *)rguid1)[0] == ((const DWORD *)rguid2)[0] &&   \
        ((const DWORD *)rguid1)[1] == ((const DWORD *)rguid2)[1] &&    \
        ((const DWORD *)rguid1)[2] == ((const DWORD *)rguid2)[2] &&    \
        ((const DWORD *)rguid1)[3] == ((const DWORD *)rguid2)[3])

#define IsEqualGUID(rguid1, rguid2) (!memcmp(rguid1, rguid2,sizeof(GUID)))

#endif  // __cplusplus

#ifdef __INLINE_ISEQUAL_GUID
#undef IsEqualGUID
#define IsEqualGUID(rguid1, rguid2) InlineIsEqualGUID(rguid1, rguid2)
#endif

// Same type, different name

#define IsEqualIID(riid1, riid2) IsEqualGUID(riid1, riid2)
#define IsEqualCLSID(rclsid1, rclsid2) IsEqualGUID(rclsid1, rclsid2)

#endif  // __midl
#endif
